@@ -1,7 +1,7 @@
 /*---------------------------------------------------------------------------*/
 /* Program to get/set some ACPI settings                                     */
 /* Author : David Leemans   -   http://freeunix.dyndns.org:8000/             */
-/* Last update : 24-07-2008                                                  */
+/* Last update : 16-10-2008                                                  */
 /*---------------------------------------------------------------------------*/
 /*                                                                           */
 /* acpitool.cpp                                                              */
@@ -28,12 +28,21 @@
 #include <config.h>
 #endif
 
+// C stdlib
 #include <cstdlib>
 #include <cstring>
+#include <cassert>
+
+// C++ stdlib
 #include <iostream>
 #include <iomanip>
 #include <fstream>
+#include <string>
+#include <vector>
+
+// system libs
 #include <dirent.h>
+
 #include "acpitool.h"
 #include "ac_adapter.h"
 #include "thinkpad.h"
@@ -44,8 +53,8 @@
 
 using namespace std;
 
-#define App_Version  "AcpiTool v0.5"
-#define Release_Date "24-Jul-2008"
+#define App_Version  "AcpiTool v0.5.1"
+#define Release_Date "13-Aug-2009"
 
 int Kernel_24 = 0, Kernel_26 = 0;
 int Use_Sys = 0, Use_Proc = 0;
@@ -210,8 +219,9 @@ int Set_Kernel_Version()
 int Do_Thermal_Info(const int show_trip, int verbose)
 {
     ifstream file_in, file_in2;
-    char *dirname, filename[15][75], str[120];
-    int tz_count = 0;
+    char *dirname, str[120];
+    vector<string> filename;
+    
     DIR *thermal_dir;
     char *name;
     char Temperature[5], State[5];
@@ -231,18 +241,26 @@ int Do_Thermal_Info(const int show_trip, int verbose)
 	    perror("scandir");
 	else
 	{
+	    char tmp_fname[256];
 	    while(n--)
 	    {
 		name = namelist[n]->d_name;
 		// skip . and .. //
-		if (!strncmp (".", name, 1) || !strncmp ("..", name, 2)) continue;
-		   		
-		sprintf(filename[tz_count], "/proc/acpi/thermal_zone/%s/state", name);
-       		tz_count++;
-       		sprintf(filename[tz_count], "/proc/acpi/thermal_zone/%s/temperature", name);
-		tz_count++;
-		sprintf(filename[tz_count], "/proc/acpi/thermal_zone/%s/trip_points", name);
-		tz_count++;
+		if (!strcmp (".", name) || !strcmp ("..", name))
+		{
+		    // do nothing
+		}
+		else
+		{
+		    snprintf(tmp_fname, sizeof (tmp_fname) - 1, "/proc/acpi/thermal_zone/%s/state", name);
+		    filename.push_back(tmp_fname);
+
+		    snprintf(tmp_fname, sizeof (tmp_fname) - 1, "/proc/acpi/thermal_zone/%s/temperature", name);
+		    filename.push_back(tmp_fname);
+
+		    snprintf(tmp_fname, sizeof (tmp_fname) - 1, "/proc/acpi/thermal_zone/%s/trip_points", name);
+		    filename.push_back(tmp_fname);
+		}
 		free(namelist[n]);
 	    }
 	    free(namelist);
@@ -263,34 +281,35 @@ int Do_Thermal_Info(const int show_trip, int verbose)
     	}	
     }
     closedir(thermal_dir);  
-    
+
+    int tz_count = filename.size();
     if(tz_count>0)     
     {
     	
 	tz_count--;
 	int tz=0;	
 	
-    	for(int i=tz_count; i>0; i-=3)     //process entries in reverse order //
+    	for(int i=tz_count; i>1; i-=3)     //process entries in reverse order //
     	{
-    	    file_in.open(filename[i-2]);
+    	    file_in.open(filename[i-2].c_str());
     	    if(file_in)                   
     	    {
     		file_in.getline(str, 120);
-    		strncpy(State, str+25, 5);
+    		strncpy(State, str+25, 5); State[4] = '\0';
     		cout<<"  Thermal zone "<<++tz<<" : "<<State<<", ";
     	    }
 	    file_in.close();
-	    file_in2.open(filename[i-1]);
+	    file_in2.open(filename[i-1].c_str());
     	    if(file_in2)                   
     	    {
 		file_in2.getline(str, 120);
-    		strncpy(Temperature, str+25, 5);
+    		strncpy(Temperature, str+25, 5); Temperature[4] = '\0';
     		cout<<Temperature<<endl;
 	    }
 	    file_in2.close();
 	    if(show_trip)           // show trip_points ? //
 	    {
-		FILE *fp = fopen(filename[i], "r");           
+		FILE *fp = fopen(filename[i].c_str(), "r");           
 		
 		/* using classic FILE and fopen here because ifstream.open fails mysteriously when asigned to multiple files ???? */
 		
@@ -352,7 +371,7 @@ int Do_Fan_Info(int verbose)
 		{
 			name = fan_dirent->d_name;
 			// skip . and .. // 
-			if (!strncmp (".", name, 1) || !strncmp ("..", name, 2)) continue;
+			if (!strcmp (".", name) || !strcmp ("..", name)) continue;
 			sprintf(filename[fan_count], "/proc/acpi/fan/%s/state", name);
 			fan_count++;
 		}
@@ -558,8 +577,8 @@ int Show_Help()
     "   -a, --ac_adapter   AC adapter information\n"    //Added by ufoalien:
     "   -A, --Asus         show supported Asus ACPI extensions (LCD brightness level, video out routing DSTD/acpi4asus info)\n"
     "   -b                 battery status, available batteries only\n"
-    "   -c, --cpu          CPU information (type, speed, cache size, frequency scaling, c-states, . . .)\n"
     "   -B, --battery      battery status, all info on all battery entries\n"
+    "   -c, --cpu          CPU information (type, speed, cache size, frequency scaling, c-states, . . .)\n"
     "   -e                 show just about everything\n"
     "   -f, --fan          show fan status\n"
     "   -F x               force fan on (x=1) or switch back to auto mode (x=0). (Toshiba only)\n"
