@@ -56,8 +56,6 @@ int Do_AC_Info(int verbose);
 
 int Do_Fan_Info(int verbose);
 
-int Get_Battery_Info(const int bat_nr, Battery_Info *bat_info, int verbose);
-int Count_Batteries();
 int Do_Battery_Stuff(int show_empty, int bat_info_level, int quiet);
 
 int Has_ACPI(char *c);
