@@ -28,7 +28,7 @@
 #define BATTERY_H
 
 int Get_Battery_Info_from_Proc(const int bat_nr, Battery_Info *bat_info, int verbose);
-int Get_Battery_Info_from_Sys(const int bat_nr, Battery_Info *bat_info, int verbose);
+int Get_Battery_Info_from_Sys(const int bat_nr, Battery_Info *batt_info, int verbose);
 
 int Count_Batteries_ProcFS();
 int Count_Batteries_SysFS();
