@@ -1,7 +1,7 @@
 /*---------------------------------------------------------------------------*/
 /* Program to get/set some ACPI settings                                     */
 /* Author : David Leemans   -   http://freeunix.dyndns.org:8000/             */
-/* Last update : 21-07-2008                                                  */
+/* Last update : 13-08-2009                                                  */
 /*---------------------------------------------------------------------------*/
 /*                                                                           */
 /* cpu.cpp                                                                   */
@@ -29,10 +29,14 @@
 
 #include <cstdlib>
 #include <cstring>
+#include <cassert>
+
 #include <iostream>
 #include <iomanip>
 #include <fstream>
+
 #include <dirent.h>
+
 #include "acpitool.h"
 #include "cpu.h"
 #include "freq.h"
@@ -69,7 +73,7 @@ int Show_CPU_Info()
 		    Show_Freq_Info();          // show freq scaling info if we have it //
 		else
 		{
-		    bzero(temp, 130);           
+		    memset(temp, '\0', 130);           
 		    sscanf(str, "%*[^:] %*s %s",temp);                    // ignore all up till :,  then ignore the :, then use what's left //
 		    printf("  CPU speed              : %s MHz \n", temp);
 		}
@@ -116,16 +120,25 @@ int Show_CPU_Info()
 			{
 				name = namelist[n]->d_name;
 				// skip . and .. //
-				if (!strncmp (".", name, 1) || !strncmp ("..", name, 2)) continue;
+				if (!strcmp (".", name) || !strcmp ("..", name))
+				{
+				    // do nothing
+				}
+				else
+				{
+				    assert (findex < 25);
+				    sprintf(filename[findex], "/proc/acpi/processor/%s/info", name);
+				    findex++;
 
-				sprintf(filename[findex], "/proc/acpi/processor/%s/info", name);
-				findex++;
-				sprintf(filename[findex], "/proc/acpi/processor/%s/power", name);
-				findex++;
-				sprintf(filename[findex], "/proc/acpi/processor/%s/throttling", name);
-				findex++;
-				cpu_count++;
+				    assert (findex < 25);
+				    sprintf(filename[findex], "/proc/acpi/processor/%s/power", name);
+				    findex++;
 
+				    assert (findex < 25);
+				    sprintf(filename[findex], "/proc/acpi/processor/%s/throttling", name);
+				    findex++;
+				    cpu_count++;
+				}
 				free(namelist[n]);
 			}
 			free(namelist);
