@@ -1,7 +1,7 @@
 /*---------------------------------------------------------------------------*/
 /* Program to get/set some ACPI settings                                     */
 /* Author : David Leemans   -   http://freeunix.dyndns.org:8000/             */
-/* Last update : 19-01-2006                                                  */
+/* Last update : 24-03-2008                                                  */
 /*---------------------------------------------------------------------------*/
 /*					                       		     */
 /* main.cpp                             				     */
@@ -27,6 +27,7 @@
 #include <config.h>
 #endif
 
+#include <cstdlib>
 #include <iostream>
 #include <iomanip>
 #include <fstream>
@@ -60,11 +61,11 @@ int main(int argc, char *argv[])
     int info_level = 0;       // verbosity level //
     int verbose = 0;            // do not print error messages , just show "not available" //
     int rc = 0;
+    char Acpi_Version[10];
     
-    if(!Has_ACPI())
+    if(!Has_ACPI(Acpi_Version))
     {
     	Show_App_Version();
-	cout<<"Seems like this system lacks ACPI support or else /proc/acpi is not the place to look for ?"<<endl;
 	return -1;
     }
     
