@@ -1,7 +1,7 @@
 /*---------------------------------------------------------------------------*/
 /* Program to get/set some ACPI settings                                     */
 /* Author : David Leemans   -   http://freeunix.dyndns.org:8000/             */
-/* Last update : 06-11-2007                                                  */
+/* Last update : 16-10-2008                                                  */
 /*---------------------------------------------------------------------------*/
 /*									     */
 /* toshiba.cpp								     */	
@@ -29,9 +29,11 @@
 #endif
 
 #include <cstdlib>
+#include <cstring>
 #include <iostream>
 #include <iomanip>
 #include <fstream>
+#include <string.h>
 #include "toshiba.h"
 
 using namespace std;
